Documentation
¶
Index ¶
- func NewFilteredSuggestionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewSuggestionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type Interface
- type SuggestionInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredSuggestionInformer ¶
func NewFilteredSuggestionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredSuggestionInformer constructs a new informer for Suggestion type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewSuggestionInformer ¶
func NewSuggestionInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewSuggestionInformer constructs a new informer for Suggestion type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// Suggestions returns a SuggestionInformer.
Suggestions() SuggestionInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type SuggestionInformer ¶
type SuggestionInformer interface {
Informer() cache.SharedIndexInformer
Lister() suggestionsv1beta1.SuggestionLister
}
SuggestionInformer provides access to a shared informer and lister for Suggestions.